@@ -16,4 +16,10 @@ def generate_tool_call_id() -> str:
     length = 24
     random_string = ''.join(random.choices(characters, k=length))
     
-    return prefix + random_string
\ No newline at end of file
+    return prefix + random_string
+
+def get_sub_agent_id_from_oas_by_name(agent_name: str, oas: dict) -> str | None:
+    return next(
+        (k.lstrip('/') for k in oas.get("paths", {}) if oas["paths"][k].get("get", {}).get("operationId") == agent_name),
+        None
+    )
