@@ -15,7 +15,7 @@ class SDKAdapter:
 
     agent: Agent
 
-    def __init__(self, api_key: str, agent_id: str, base_url: Optional[str] = None, organization_id: Optional[str] = None):
+    def __init__(self, api_key: str, agent_id: str, base_url: Optional[str] = None, organization_id: Optional[str] = None, should_reset_cache: Optional[bool] = False):
         """
         Initialize the SDKAdapter with the provided API key and agent ID.
 
@@ -25,7 +25,7 @@ class SDKAdapter:
             base_url (Optional[str], optional): The base URL for the xpander.ai API. Defaults to None.
             organization_id (Optional[str], optional): The organization ID, if applicable. Defaults to None.
         """
-        self.xpander_client = XpanderClient(api_key=api_key, base_url=base_url, organization_id=organization_id)
+        self.xpander_client = XpanderClient(api_key=api_key, base_url=base_url, organization_id=organization_id,should_reset_cache=should_reset_cache)
         self.agent = self.xpander_client.agents.get(agent_id=agent_id)
 
     def get_system_prompt(self) -> str:
