@@ -10,6 +10,7 @@ from xpander_sdk import (
     ToolCallResult,
     LLMProvider,
 )
+from ...generic import get_sub_agent_id_from_oas_by_name
 from .base import SDKAdapter
 import chainlit as cl
 from chainlit.data.base import BaseDataLayer
@@ -536,8 +537,14 @@ class ChainlitAdapter(SDKAdapter):
             is_agent_end_tool = True if tool_call.name == AGENT_END_TOOL else False
             
             current_step = cl.context.current_step
-            
             tool_name = tool_call.name
+            
+            tool_agent_id = get_sub_agent_id_from_oas_by_name(agent_name=tool_call.name,oas=self.agent.oas)
+            if tool_agent_id:
+                sub_agent_node = self.agent.graph.find_node_by_item_id(item_id=tool_agent_id)
+                if sub_agent_node:
+                    tool_name = sub_agent_node.name
+                    
             if is_sub_agent:
                 if is_agent_end_tool:
                     tool_name = f"-> {self.agent.name} (Sub agent) -> Thought & Finish"
@@ -582,8 +589,9 @@ class ChainlitAdapter(SDKAdapter):
                 current_step.output = tool_call_result.result
                 current_step.language = "json"
                     
-            if is_agent_end_tool:
+            if is_agent_end_tool and not is_sub_agent:
                 await current_step.remove()
+                tool_calls.clear()
                 return tool_call_result.payload['bodyParams']['result']
 
         # Reset tool calls
